Zoom XBlock |Build Status| |Coveralls|
----------------------------------------------


TBD: Add details here.



.. |Build Status| image:: https://travis-ci.org/edx/edx-zoom.svg
  :target: https://travis-ci.org/edx/edx-zoom

.. |Coveralls| image:: https://coveralls.io/repos/edx/edx-zoom/badge.svg?branch=master&service=github
  :target: https://coveralls.io/github/edx/edx-zoom?branch=master
